@@ -311,7 +311,7 @@ namespace boost { namespace polygon{
             at1->copyHoles(*(at1->otherTailp_));
             //std::cout << "test2\n";
             //Polygon45WithHolesImpl<PolyLine45PolygonData> poly(polyData);
-            //std::cout << poly << std::endl;
+            //std::cout << poly << "\n";
             //std::cout << "test3\n";
             typedef typename cT::value_type pType;
             output.push_back(pType());
@@ -319,14 +319,14 @@ namespace boost { namespace polygon{
             typename PolyLineByConcept<Unit, cType>::type polyData(at1);
             assign(output.back(), polyData);
             //std::cout << "test4\n";
-            //std::cout << "delete " << at1->otherTailp_ << std::endl;
+            //std::cout << "delete " << at1->otherTailp_ << "\n";
             //at1->print();
             //at1->otherTailp_->print();
             delete at1->otherTailp_;
             //at1->print();
             //at1->otherTailp_->print();
             //std::cout << "test5\n";
-            //std::cout << "delete " << at1 << std::endl;
+            //std::cout << "delete " << at1 << "\n";
             delete at1;
             //std::cout << "test6\n";
             return 0;
@@ -345,7 +345,7 @@ namespace boost { namespace polygon{
 
       inline void destroyContents() {
         if(otherTailp_) {
-          //std::cout << "delete p " << tailp_ << std::endl;
+          //std::cout << "delete p " << tailp_ << "\n";
           if(tailp_) delete tailp_;
           tailp_ = 0;
           otherTailp_->otherTailp_ = 0;
@@ -353,7 +353,7 @@ namespace boost { namespace polygon{
           otherTailp_ = 0;
         }
         for(typename std::list<ActiveTail45*>::iterator itr = holesList_.begin(); itr != holesList_.end(); ++itr) {
-          //std::cout << "delete p " << (*itr) << std::endl;
+          //std::cout << "delete p " << (*itr) << "\n";
           if(*itr) {
             if((*itr)->otherTailp_) {
               delete (*itr)->otherTailp_;
@@ -367,7 +367,7 @@ namespace boost { namespace polygon{
       }
 
 //       inline void print() {
-//         std::cout << this << " " << tailp_ << " " << otherTailp_ << " " << holesList_.size() << " " << head_ << std::endl;
+//         std::cout << this << " " << tailp_ << " " << otherTailp_ << " " << holesList_.size() << " " << head_ << "\n";
 //       }
 
       static inline std::pair<ActiveTail45*, ActiveTail45*> createActiveTail45sAsPair(Point point, bool solid,
@@ -575,9 +575,9 @@ namespace boost { namespace polygon{
         while(inputBegin != inputEnd) {
           //std::cout << "2\n";
           x_ = (*inputBegin).pt.x();
-          //std::cout << "SCAN FORMATION " << x_ << std::endl;
-          //std::cout << "x_ = " << x_ << std::endl;
-          //std::cout << "scan line size: " << scanData_.size() << std::endl;
+          //std::cout << "SCAN FORMATION " << x_ << "\n";
+          //std::cout << "x_ = " << x_ << "\n";
+          //std::cout << "scan line size: " << scanData_.size() << "\n";
           inputBegin = processEvent_(output, inputBegin, inputEnd);
         }
       }
@@ -587,7 +587,7 @@ namespace boost { namespace polygon{
       template <class cT, class cT2>
       inline std::pair<int, ActiveTail45*> processPoint_(cT& output, cT2& elements, Point point,
                                                          Vertex45Count& counts, ActiveTail45** tails, Vertex45Count& incoming) {
-        //std::cout << point << std::endl;
+        //std::cout << point << "\n";
         //std::cout << counts[0] << " ";
         //std::cout << counts[1] << " ";
         //std::cout << counts[2] << " ";
@@ -600,14 +600,14 @@ namespace boost { namespace polygon{
         ActiveTail45* returnValue = 0;
         int returnCount = 0;
         for(int i = 0; i < 3; ++i) {
-          //std::cout << i << std::endl;
+          //std::cout << i << "\n";
           if(counts[i] == -1) {
             //std::cout << "fixed i\n";
             for(int j = i + 1; j < 4; ++j) {
-              //std::cout << j << std::endl;
+              //std::cout << j << "\n";
               if(counts[j]) {
                 if(counts[j] == 1) {
-                  //std::cout << "case1: " << i << " " << j << std::endl;
+                  //std::cout << "case1: " << i << " " << j << "\n";
                   //if a figure is closed it will be written out by this function to output
                   ActiveTail45::joinChains(point, tails[i], tails[j], true, output);
                   counts[i] = 0;
@@ -623,14 +623,14 @@ namespace boost { namespace polygon{
         //find any pairs of incoming edges that need to create pair for leading solid
         //std::cout << "checking case2\n";
         for(int i = 0; i < 3; ++i) {
-          //std::cout << i << std::endl;
+          //std::cout << i << "\n";
           if(incoming[i] == 1) {
             //std::cout << "fixed i\n";
             for(int j = i + 1; j < 4; ++j) {
-              //std::cout << j << std::endl;
+              //std::cout << j << "\n";
               if(incoming[j]) {
                 if(incoming[j] == -1) {
-                  //std::cout << "case2: " << i << " " << j << std::endl;
+                  //std::cout << "case2: " << i << " " << j << "\n";
                   //std::cout << "creating active tail pair\n";
                   std::pair<ActiveTail45*, ActiveTail45*> tailPair =
                     ActiveTail45::createActiveTail45sAsPair(point, true, 0, fractureHoles_ != 0);
@@ -642,10 +642,10 @@ namespace boost { namespace polygon{
                     returnCount = 1;
                   } else {
                     Vertex45 vertex(point, i -1, incoming[i]);
-                    //std::cout << "new element " << j-1 << " " << -1 << std::endl;
+                    //std::cout << "new element " << j-1 << " " << -1 << "\n";
                     elements.push_back(std::pair<Vertex45, ActiveTail45*>(Vertex45(point, j -1, -1), tailPair.first));
                   }
-                  //std::cout << "new element " << i-1 << " " << 1 << std::endl;
+                  //std::cout << "new element " << i-1 << " " << 1 << "\n";
                   elements.push_back(std::pair<Vertex45, ActiveTail45*>(Vertex45(point, i -1, 1), tailPair.second));
                   incoming[i] = 0;
                   incoming[j] = 0;
@@ -662,14 +662,14 @@ namespace boost { namespace polygon{
         //find pass through with solid on top
         //std::cout << "checking case 3\n";
         for(int i = 0; i < 4; ++i) {
-          //std::cout << i << std::endl;
+          //std::cout << i << "\n";
           if(counts[i] != 0) {
             if(counts[i] == 1) {
               //std::cout << "fixed i\n";
               for(int j = 3; j >= 0; --j) {
                 if(incoming[j] != 0) {
                   if(incoming[j] == 1) {
-                    //std::cout << "case3: " << i << " " << j << std::endl;
+                    //std::cout << "case3: " << i << " " << j << "\n";
                     //tails[i]->print();
                     //pass through solid on top
                     tails[i]->pushPoint(point);
@@ -699,14 +699,14 @@ namespace boost { namespace polygon{
               for(int j = 0; j < 4; ++j) {
                 if(incoming[j] != 0) {
                   if(incoming[j] == -1) {
-                    //std::cout << "case4: " << i << " " << j << std::endl;
+                    //std::cout << "case4: " << i << " " << j << "\n";
                     //pass through solid on bottom
                     tails[i]->pushPoint(point);
                     if(j == 3) {
                       returnValue = tails[i];
                       returnCount = 1;
                     } else {
-                      //std::cout << "new element " << j-1 << " " << incoming[j] << std::endl;
+                      //std::cout << "new element " << j-1 << " " << incoming[j] << "\n";
                       elements.push_back(std::pair<Vertex45, ActiveTail45*>(Vertex45(point, j -1, incoming[j]), tails[i]));
                     }
                     tails[i] = 0;
@@ -728,7 +728,7 @@ namespace boost { namespace polygon{
           if(counts[i] != 0) {
             for(int j = i+1; j < 4; ++j) {
               if(counts[j] != 0) {
-                //std::cout << "case5: " << i << " " << j << std::endl;
+                //std::cout << "case5: " << i << " " << j << "\n";
                 //we are ending a hole and may potentially close a figure and have to handle the hole
                 returnValue = ActiveTail45::joinChains(point, tails[i], tails[j], false, output);
                 tails[i] = 0;
@@ -746,7 +746,7 @@ namespace boost { namespace polygon{
           if(incoming[i] != 0) {
             for(int j = i+1; j < 4; ++j) {
               if(incoming[j] != 0) {
-                //std::cout << "case6: " << i << " " << j << std::endl;
+                //std::cout << "case6: " << i << " " << j << "\n";
                 //we are beginning a empty space
                 ActiveTail45* holep = 0;
                 if(counts[3] == 0) holep = tails[3];
@@ -756,10 +756,10 @@ namespace boost { namespace polygon{
                   returnValue = tailPair.first;
                   returnCount = -1;
                 } else {
-                  //std::cout << "new element " << j-1 << " " << incoming[j] << std::endl;
+                  //std::cout << "new element " << j-1 << " " << incoming[j] << "\n";
                   elements.push_back(std::pair<Vertex45, ActiveTail45*>(Vertex45(point, j -1, incoming[j]), tailPair.first));
                 }
-                //std::cout << "new element " << i-1 << " " << incoming[i] << std::endl;
+                //std::cout << "new element " << i-1 << " " << incoming[i] << "\n";
                 elements.push_back(std::pair<Vertex45, ActiveTail45*>(Vertex45(point, i -1, incoming[i]), tailPair.second));
                 incoming[i] = 0;
                 incoming[j] = 0;
@@ -798,7 +798,7 @@ namespace boost { namespace polygon{
             //std::cout << "loop2\n";
             elementIters.push_back(iter);
             int index = iter->first.rise + 1;
-            //std::cout << index << " " << iter->first.count << std::endl;
+            //std::cout << index << " " << iter->first.count << "\n";
             counts[index] = iter->first.count;
             tails[index] = iter->second;
             ++iter;
@@ -834,7 +834,7 @@ namespace boost { namespace polygon{
           verticalCount = result.first;
           verticalTail = result.second;
           //if(verticalTail) std::cout << "have vertical tail\n";
-          //std::cout << "verticalCount: " << verticalCount << std::endl;
+          //std::cout << "verticalCount: " << verticalCount << "\n";
           if(verticalTail && !verticalCount) {
             //we got a hole out of the point we just processed
             //iter is still at the next y element above the current y value in the tree
@@ -906,9 +906,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(10, 10), 0, 1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon formation\n";
       return true;
@@ -930,9 +930,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(10, 20), 1, 1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon formation\n";
       return true;
@@ -955,9 +955,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(20, 10), 0, 1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon formation\n";
       return true;
@@ -1020,9 +1020,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(12, 8), -1, 1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon formation\n";
       return true;
@@ -1053,9 +1053,9 @@ namespace boost { namespace polygon{
 
       polygon_sort(result.begin(), result.end());
       pf.scan(polys, result.begin(), result.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon formation\n";
       return true;
@@ -1125,9 +1125,9 @@ namespace boost { namespace polygon{
 
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon formation\n";
       return true;
@@ -1197,9 +1197,9 @@ namespace boost { namespace polygon{
 
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon formation\n";
       return true;
@@ -1241,9 +1241,9 @@ namespace boost { namespace polygon{
 
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon formation\n";
       return true;
@@ -1289,9 +1289,9 @@ namespace boost { namespace polygon{
         while(inputBegin != inputEnd) {
           //std::cout << "2\n";
           x_ = (*inputBegin).pt.x();
-          //std::cout << "SCAN FORMATION " << x_ << std::endl;
-          //std::cout << "x_ = " << x_ << std::endl;
-          //std::cout << "scan line size: " << scanData_.size() << std::endl;
+          //std::cout << "SCAN FORMATION " << x_ << "\n";
+          //std::cout << "x_ = " << x_ << "\n";
+          //std::cout << "scan line size: " << scanData_.size() << "\n";
           inputBegin = processEvent_(output, inputBegin, inputEnd);
         }
       }
@@ -1316,7 +1316,7 @@ namespace boost { namespace polygon{
                                                          std::pair<ActiveTail45*, ActiveTail45*>& verticalPair,
                                                          iterator previter, Point point,
                                                          Vertex45Count& counts, ActiveTail45** tails, Vertex45Count& incoming) {
-        //std::cout << point << std::endl;
+        //std::cout << point << "\n";
         //std::cout << counts[0] << " ";
         //std::cout << counts[1] << " ";
         //std::cout << counts[2] << " ";
@@ -1332,14 +1332,14 @@ namespace boost { namespace polygon{
         verticalPairOut.second = 0;
         int returnCount = 0;
         for(int i = 0; i < 3; ++i) {
-          //std::cout << i << std::endl;
+          //std::cout << i << "\n";
           if(counts[i] == -1) {
             //std::cout << "fixed i\n";
             for(int j = i + 1; j < 4; ++j) {
-              //std::cout << j << std::endl;
+              //std::cout << j << "\n";
               if(counts[j]) {
                 if(counts[j] == 1) {
-                  //std::cout << "case1: " << i << " " << j << std::endl;
+                  //std::cout << "case1: " << i << " " << j << "\n";
                   //if a figure is closed it will be written out by this function to output
                   ActiveTail45::joinChains(point, tails[i], tails[j], true, output);
                   counts[i] = 0;
@@ -1355,14 +1355,14 @@ namespace boost { namespace polygon{
         //find any pairs of incoming edges that need to create pair for leading solid
         //std::cout << "checking case2\n";
         for(int i = 0; i < 3; ++i) {
-          //std::cout << i << std::endl;
+          //std::cout << i << "\n";
           if(incoming[i] == 1) {
             //std::cout << "fixed i\n";
             for(int j = i + 1; j < 4; ++j) {
-              //std::cout << j << std::endl;
+              //std::cout << j << "\n";
               if(incoming[j]) {
                 if(incoming[j] == -1) {
-                  //std::cout << "case2: " << i << " " << j << std::endl;
+                  //std::cout << "case2: " << i << " " << j << "\n";
                   //std::cout << "creating active tail pair\n";
                   std::pair<ActiveTail45*, ActiveTail45*> tailPair =
                     ActiveTail45::createActiveTail45sAsPair(point, true, 0, false);
@@ -1374,10 +1374,10 @@ namespace boost { namespace polygon{
                     returnCount = 1;
                   } else {
                     Vertex45 vertex(point, i -1, incoming[i]);
-                    //std::cout << "new element " << j-1 << " " << -1 << std::endl;
+                    //std::cout << "new element " << j-1 << " " << -1 << "\n";
                     elements.push_back(std::pair<Vertex45, ActiveTail45*>(Vertex45(point, j -1, -1), tailPair.first));
                   }
-                  //std::cout << "new element " << i-1 << " " << 1 << std::endl;
+                  //std::cout << "new element " << i-1 << " " << 1 << "\n";
                   elements.push_back(std::pair<Vertex45, ActiveTail45*>(Vertex45(point, i -1, 1), tailPair.second));
                   incoming[i] = 0;
                   incoming[j] = 0;
@@ -1394,14 +1394,14 @@ namespace boost { namespace polygon{
         //find pass through with solid on top
         //std::cout << "checking case 3\n";
         for(int i = 0; i < 4; ++i) {
-          //std::cout << i << std::endl;
+          //std::cout << i << "\n";
           if(counts[i] != 0) {
             if(counts[i] == 1) {
               //std::cout << "fixed i\n";
               for(int j = 3; j >= 0; --j) {
                 if(incoming[j] != 0) {
                   if(incoming[j] == 1) {
-                    //std::cout << "case3: " << i << " " << j << std::endl;
+                    //std::cout << "case3: " << i << " " << j << "\n";
                     //tails[i]->print();
                     //pass through solid on top
                     if(i != 3)
@@ -1437,10 +1437,10 @@ namespace boost { namespace polygon{
               for(int j = 0; j < 4; ++j) {
                 if(incoming[j] != 0) {
                   if(incoming[j] == -1) {
-                    //std::cout << "case4: " << i << " " << j << std::endl;
+                    //std::cout << "case4: " << i << " " << j << "\n";
                     //pass through solid on bottom
                     if(i == 3) {
-                      //std::cout << "new element " << j-1 << " " << incoming[j] << std::endl;
+                      //std::cout << "new element " << j-1 << " " << incoming[j] << "\n";
                       if(j == 3) {
                         returnValue = tails[i];
                         returnCount = 1;
@@ -1483,7 +1483,7 @@ namespace boost { namespace polygon{
           if(counts[i] != 0) {
             for(int j = i+1; j < 4; ++j) {
               if(counts[j] != 0) {
-                //std::cout << "case5: " << i << " " << j << std::endl;
+                //std::cout << "case5: " << i << " " << j << "\n";
                 //we are ending a hole and may potentially close a figure and have to handle the hole
                 tails[i]->pushPoint(point);
                 verticalPairOut.first = tails[i];
@@ -1511,7 +1511,7 @@ namespace boost { namespace polygon{
           if(incoming[i] != 0) {
             for(int j = i+1; j < 4; ++j) {
               if(incoming[j] != 0) {
-                //std::cout << "case6: " << i << " " << j << std::endl;
+                //std::cout << "case6: " << i << " " << j << "\n";
                 //we are beginning a empty space
                 if(verticalPair.first == 0) {
                   getVerticalPair_(verticalPair, previter);
@@ -1523,12 +1523,12 @@ namespace boost { namespace polygon{
                 } else {
                   std::pair<ActiveTail45*, ActiveTail45*> tailPair =
                     ActiveTail45::createActiveTail45sAsPair(point, true, 0, false);
-                  //std::cout << "new element " << j-1 << " " << incoming[j] << std::endl;
+                  //std::cout << "new element " << j-1 << " " << incoming[j] << "\n";
                   elements.push_back(std::pair<Vertex45, ActiveTail45*>(Vertex45(point, j -1, incoming[j]), tailPair.second));
                   verticalPairOut.second = tailPair.first;
                   verticalPairOut.first = verticalPair.first;
                 }
-                //std::cout << "new element " << i-1 << " " << incoming[i] << std::endl;
+                //std::cout << "new element " << i-1 << " " << incoming[i] << "\n";
                 elements.push_back(std::pair<Vertex45, ActiveTail45*>(Vertex45(point, i -1, incoming[i]), verticalPair.second));
                 incoming[i] = 0;
                 incoming[j] = 0;
@@ -1578,7 +1578,7 @@ namespace boost { namespace polygon{
             //std::cout << "loop2\n";
             elementIters.push_back(iter);
             int index = iter->first.rise + 1;
-            //std::cout << index << " " << iter->first.count << std::endl;
+            //std::cout << index << " " << iter->first.count << "\n";
             counts[index] = iter->first.count;
             tails[index] = iter->second;
             ++iter;
@@ -1670,9 +1670,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(10, 10), 0, 1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -1694,9 +1694,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(10, 20), 1, 1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -1718,9 +1718,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(20, 10), 0, 1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -1744,9 +1744,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(20, 20), 2, 1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -1770,9 +1770,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(20, -10), 2, -1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -1803,9 +1803,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(3, 2), 0, -1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -1837,9 +1837,9 @@ namespace boost { namespace polygon{
 
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -1901,9 +1901,9 @@ namespace boost { namespace polygon{
       data.push_back(Vertex45(Point(12, 8), -1, 1));
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -1935,9 +1935,9 @@ namespace boost { namespace polygon{
 
       polygon_sort(result.begin(), result.end());
       pf.scan(polys, result.begin(), result.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -2007,9 +2007,9 @@ namespace boost { namespace polygon{
 
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -2079,9 +2079,9 @@ namespace boost { namespace polygon{
 
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
@@ -2123,9 +2123,9 @@ namespace boost { namespace polygon{
 
       polygon_sort(data.begin(), data.end());
       pf.scan(polys, data.begin(), data.end());
-      stdcout << "result size: " << polys.size() << std::endl;
+      stdcout << "result size: " << polys.size() << "\n";
       for(std::size_t i = 0; i < polys.size(); ++i) {
-        stdcout << polys[i] << std::endl;
+        stdcout << polys[i] << "\n";
       }
       stdcout << "done testing polygon tiling\n";
       return true;
